pub struct MapAsync<F, H> {
pub handler: H,
pub f: F,
}Fields
handler: Hf: FTrait Implementations
impl<F: Copy, H: Copy> Copy for MapAsync<F, H>
impl<F: Eq, H: Eq> Eq for MapAsync<F, H>
Sourceimpl<F, H, T, E> Handler<T, E> for MapAsync<F, H>
impl<F, H, T, E> Handler<T, E> for MapAsync<F, H>
type Output = <H as Handler<<F as Fn1ResultAsync<T, E>>::Ok, E>>::Output
fn handle<'a>( &'a self, request: T, ) -> impl Future<Output = Result<Self::Output, E>> + Send + Captures<(&'a Self, T)>
Sourcefn after<C>(self, current: C) -> Seq<C, Self>where
C: SeqHandler<T, E, Self>,
Self: Sized,
fn after<C>(self, current: C) -> Seq<C, Self>where
C: SeqHandler<T, E, Self>,
Self: Sized,
Run this handler after specified, specified handler must
implement
SeqHandler to create something meaningfulSourcefn or<R, EE>(self, rhs: R) -> Or<Self, R>
fn or<R, EE>(self, rhs: R) -> Or<Self, R>
Logical or for handlers, refer to
Or for documentationSourcefn serve<X, OTx, SRx>(
self,
rx: X,
options: ServeOptions<OTx, SRx>,
) -> impl Future<Output = Result<(), E>> + Send
fn serve<X, OTx, SRx>( self, rx: X, options: ServeOptions<OTx, SRx>, ) -> impl Future<Output = Result<(), E>> + Send
Sourcefn into_server<X>(self, rx: X) -> Server<Self, X>
fn into_server<X>(self, rx: X) -> Server<Self, X>
Creates server from that handler, for more, see docs for
Server handlerSourcefn provide<Env, F>(self, env: Env, f: F) -> Provide<Env, F, Self>where
Self: Sized,
fn provide<Env, F>(self, env: Env, f: F) -> Provide<Env, F, Self>where
Self: Sized,
Special case of
Handler::map_async,
refer to Provide documentation for more.Sourcefn map_async<K, F>(self, f: F) -> MapAsync<F, Self>where
Self: Sized,
F: Fn1ResultAsync<K, E, Ok = T>,
fn map_async<K, F>(self, f: F) -> MapAsync<F, Self>where
Self: Sized,
F: Fn1ResultAsync<K, E, Ok = T>,
Same as
Handler::map, but provided function is asyncSourcefn map<K, F>(self, f: F) -> Map<F, Self>
fn map<K, F>(self, f: F) -> Map<F, Self>
Changes input of the handler into another type, to do that - it
accepts function that maps that type to input type of the current handler
Sourcefn pipe<Dst>(self, dst: Dst) -> Pipe<Self, Dst>
fn pipe<Dst>(self, dst: Dst) -> Pipe<Self, Dst>
Pipes output from one handler to
Dst, refer to docs of Pipe for more.Wraps handler in
ArcSourceimpl<F: PartialEq, H: PartialEq> PartialEq for MapAsync<F, H>
impl<F: PartialEq, H: PartialEq> PartialEq for MapAsync<F, H>
impl<F, H> StructuralPartialEq for MapAsync<F, H>